@@ -3,7 +3,7 @@ package DBIx::MyParse::Item;
 use strict;
 use warnings;
 
-our $VERSION = '0.20';
+our $VERSION = '0.40';
 
 #
 # If you change those constants, do not forget to change
@@ -66,6 +66,7 @@ sub getValue {
 	if (
 		($item_type eq 'STRING_ITEM') ||
 		($item_type eq 'INT_ITEM') ||
+		($item_type eq 'DECIMAL_ITEM') ||
 		($item_type eq 'REAL_ITEM') ||
 		($item_type eq 'VARBIN_ITEM')
 	) {
@@ -161,7 +162,7 @@ __END__
 
 =head1 NAME
 
-DBIx::MyParse::Item - Accessing the items from a C<DBIx::MyParse> parse tree
+DBIx::MyParse::Item - Accessing the items from a C<DBIx::MyParse::Query> parse tree
 
 =head1 SYNOPSIS
 
@@ -180,21 +181,21 @@ DBIx::MyParse::Item - Accessing the items from a C<DBIx::MyParse> parse tree
 =head1 DESCRIPTION
 
 MySQL uses a few dozen Item objects to store the various nodes possible in a
-parse tree. For the sake of simplicity, we only use a single object interface
-in Perl to access things.
+parse tree. For the sake of simplicity, we only use a single object type
+in Perl to represent the same information.
 
 =head1 METHODS
 
 =over 4
 
-=item my $string = $item->getType();
+=item C<< my $string = $item->getType(); >>
 
-This returns the type of the Item as a string, to facilitate dumping and debugging.
+This returns the type of the C<Item> as a string, to facilitate dumping and debugging.
 
 	if ($item_type eq 'FIELD_ITEM') { ... }	# Correct
 	if ($item_type == FIELD_ITEM) { ... }	# Will not work
 
-The possible values are listed in enum Type in sql/item.h in the MySQL source.
+The possible values are listed in C<enum Type> in F<sql/item.h> in the MySQL source.
 
 	enum Type {FIELD_ITEM, FUNC_ITEM, SUM_FUNC_ITEM, STRING_ITEM,
 		INT_ITEM, REAL_ITEM, NULL_ITEM, VARBIN_ITEM,
@@ -209,20 +210,23 @@ From those, the following are explicitly supported:
 
 	FIELD_ITEM, FUNC_ITEM, SUM_FUNC_ITEM,
 	STRING_ITEM, INT_ITEM, REAL_ITEM, NULL_ITEM, VARBIN_ITEM
-	REF_ITEM, COND_ITEM
+	REF_ITEM, COND_ITEM, PARAM_ITEM
 
-In addition, DBIx::MyParse defines its own TABLE_ITEM in case a table, rather than a field, is being
-referenced.
+In addition, L<DBIx::MyParse> defines its own C<TABLE_ITEM> in case a table,
+rather than a field, is being referenced.
 
-REF_ITEM is a FIELD_ITEM that is used in a HAVING clause. VARBIN_ITEM is
-created when a Hex value is passed to MySQL (e.g. 0x5061756c).
+C<REF_ITEM> is a C<FIELD_ITEM> that is used in a C<HAVING> clause.
+C<VARBIN_ITEM> is created when a Hex value is passed to MySQL (e.g. 0x5061756c).
+C<PARAM_ITEM> is a ?-style placeholder.
 
-=item my $string = $item->getFuncType();
+=over
 
-if $item->getType() eq "FUNC_ITEM", you can call getFuncType() to determine what type of
-function it is. For MySQL, all operators are also of type FUNC_ITEM.
+=item C<< my $string = $item->getFuncType(); >>
 
-The possible values are again strings (see above) and are listed in sql/item_func.h under enum Functype
+if C<< $item->getType() eq "FUNC_ITEM" >>, you can call C<getFuncType()> to determine what type of
+function it is. For MySQL, all operators are also of type C<FUNC_ITEM>.
+
+The possible values are again strings (see above) and are listed in F<sql/item_func.h> under C<enum Functype>
 
 	enum Functype {
 		UNKNOWN_FUNC,EQ_FUNC,EQUAL_FUNC,NE_FUNC,LT_FUNC,LE_FUNC,
@@ -238,66 +242,67 @@ The possible values are again strings (see above) and are listed in sql/item_fun
 		NOT_FUNC, NOT_ALL_FUNC, NOW_FUNC, VAR_VALUE_FUNC
 	};
 
-if $item->getType() eq "SUM_FUNC_ITEM", $item->getFuncType() can be any of the aggregate functions listed
-in enum Sumfunctype in sql/item_sum.h:
+if C<< $item->getType() eq "SUM_FUNC_ITEM" >>, C<< $item->getFuncType() >> can be any of the aggregate functions listed
+in enum Sumfunctype in F<sql/item_sum.h>:
 
-	enum Sumfunctype { COUNT_FUNC,COUNT_DISTINCT_FUNC,SUM_FUNC,AVG_FUNC,MIN_FUNC,
-		MAX_FUNC, UNIQUE_USERS_FUNC,STD_FUNC,VARIANCE_FUNC,SUM_BIT_FUNC,
-		UDF_SUM_FUNC, GROUP_CONCAT_FUNC
+	enum Sumfunctype {
+		COUNT_FUNC,COUNT_DISTINCT_FUNC,SUM_FUNC,AVG_FUNC,MIN_FUNC,
+		MAX_FUNC,UNIQUE_USERS_FUNC,STD_FUNC,VARIANCE_FUNC,SUM_BIT_FUNC,
+		UDF_SUM_FUNC,GROUP_CONCAT_FUNC
 	};
 
-For MySQL, all functions not specifically listed above are UNKNOWN_FUNC and you must call getFuncName().
+For MySQL, all functions not specifically listed above are C<UNKNOWN_FUNC> and you must call C<getFuncName()>.
 
-=item my $string = $item->getFuncName();
+=item C<< my $string = $item->getFuncName(); >>
 
 Returns the name of the function called, such as "concat_ws", "md5", etc. If $item is not a function,
 but an operator, the symbol of the operator is returned, such as "+", "||", etc. The name of the function
 will be lowercase regardless of the orginal case in the SQL string.
 
-=item my $item_array_ref = $item->getArguments();
+=item C<< my $item_array_ref = $item->getArguments(); >>
 
 Returns a reference to an array containing all the arguments to the function/operator. Each item from
 the array is an DBIx::MyParse::Item object, even if it is a simple string or a field name.
 
-=item my $string = $item->getDatabaseName();
+=item C<< my $string = $item->getDatabaseName(); >>
 
 if $item is FIELD_ITEM, REF_ITEM or a TABLE_ITEM, getDatabaseName() returns the database the field belongs to,
 if it was explicitly specified. If it was not specified explicitly, such as was given previously with a
 "USE DATABASE" command, getDatabaseName() will return undef. This may change in the future if we
 incorporate some more of MySQL's logic
 
-=item my $string = $item->getTableName();
+=item C<< my $string = $item->getTableName(); >>
 
 Returns the name of the table for a FIELD_ITEM or TABLE_ITEM object. For FIELD_ITEM, the table name must be
 explicitly specified with "table_name.field_name" notation. Otherwise returns undef and does not attempt to
 guess the name of the table.
 
-=item my $string = $item->getTableName();
+=item C<< my $string = $item->getTableName(); >>
 
 Returns the name of the field for a FIELD_ITEM object.
 
-=item my $string = $item->getValue();
+=item C<< my $string = $item->getValue(); >>
 
 Returns, as string, the value of STRING_ITEM, INT_ITEM, REAL_ITEM and VARBIN_ITEM objects. 
 
-=item my $string = $item->getOrderDir();
-=item my $string = $item->getGroupDir();
+=item C<< my $string = $item->getOrderDir(); >>
+=item C<< my $string = $item->getGroupDir(); >>
 
-For an FIELD_ITEM used in GROUP BY or ORDER BY, those two identical functions return either the string
-"ASC" or the string "DESC" depending on the group/ordering direction. Default is "ASC" and will be
-returned even if the query does not specify a direction.
+For an C<FIELD_ITEM> used in C<GROUP BY> or C<ORDER BY>, those two identical functions return either the string
+C<"ASC"> or the string C<"DESC"> depending on the group/ordering direction. Default is C<"ASC"> and will be
+returned even if the query does not specify a direction explicitly.
 
-=item my $string = $item->getAlias();
+=item C<< my $string = $item->getAlias(); >>
 
 Returns the name of the Item if provided with an AS clause, such as SELECT field AS alias.
 
-=item my $item_ref = $item->getJoinCond()
+=item C<< my $item_ref = $item->getJoinCond() >>
 
 For TABLE_ITEM Items, provides a reference to an DBIx::MyParse::Item object containing the condition under
 which the table in question will be joined to the preceding table ( the ON clause in SQL). The USING clause is
 automatically converted to an ON internally by MySQL.
 
-=item my $string = $item->getJoinType();
+=item C<< my $string = $item->getJoinType(); >>
 
 Returns, as string, the type of join that will be used. Possible values are:
 
@@ -305,19 +310,25 @@ Returns, as string, the type of join that will be used. Possible values are:
 	"JOIN_TYPE_RIGHT"
 	"JOIN_TYPE_STRAIGHT"
 
-Join type is RIGHT OUTER is currently not returned properly. This will be fixed in due time.
+Join type is C<RIGHT OUTER> is currently not returned properly. This will be fixed in due time.
 
-=item my $string_array_ref = $item->getUseIndex();
+=item C<< my $string_array_ref = $item->getUseIndex(); >>
 
-Returns a reference to an array containing one string for each index mentioned in the USE INDEX clause for the table in question.
+Returns a reference to an array containing one string for each index mentioned in the
+C<USE INDEX> clause for the table in question.
 
-This may change in the future to an array of Item objects, rather than simple strings, however at this time MySQL provides strings.
+This may change in the future to an array of C<Item> objects, rather than simple strings,
+however at this time MySQL provides strings.
 
-=item my $string_array_ref = $item->getIgnoreIndex();
+=item C<< my $string_array_ref = $item->getIgnoreIndex(); >>
 
-Returns a reference to an array containing one string for each index mentioned in an IGNORE INDEX clause for the table in question.
+Returns a reference to an array containing one string for each index mentioned in an
+C<IGNORE INDEX> clause for the table in question.
 
-This may change in the future to an array of Item objects, rather than simple strings, however at this time MySQL provides strings.
+This may change in the future to an array of C<Item> objects, rather than simple strings,
+however at this time MySQL provides strings.
+
+=back
 
 =cut
 
